# jellyfish

**DOI:** [10.5281/zenodo.8381418](https://doi.org/10.5281/zenodo.8381418)

## Available Versions
- **Version 2.3.0**
  - [Download](https://zenodo.org/record/8381419/files/jellyfish_2.3.0.img)
  - **MD5:** `b581ab486ac9ae4f4bcc5b0d3076fc1f`
  - **DOI:** [10.5281/zenodo.8381419](https://doi.org/10.5281/zenodo.8381419)
  - **Size:** 91.03 MB
  - **Binaries:** 0 available

## Binaries (1 total)

```jellyfish```
